==> lxqt-admin_0.14.0.orig.tar.gz: lxqt-admin-0.14.0/lxqt-admin-time/translations/lxqt-admin-time_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>Год:хв:сек</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <source>lxqt-admin-time-helper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>Налаштування часу і дати</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>Дата і час</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>Часова зона</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="120"/>
        <location filename="../timeadmindialog.cpp" line="130"/>
        <location filename="../timeadmindialog.cpp" line="137"/>
        <location filename="../timeadmindialog.cpp" line="147"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="155"/>
        <source>Reboot required</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Ваша теперішня часова зона:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>Фільтр</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation type="unfinished">Нічого</translation>
    </message>
</context>
</TS>

==> lxqt-admin_2.1.0.orig.tar.gz: lxqt-admin-2.1.0/lxqt-admin-time/translations/lxqt-admin-time_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>ГГ:хх:сс</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Увімкнути синхронізацію часу мережі (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC встановлено на місцевий час</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../nosdtimedatectl.cpp" line="144"/>
        <source>lxqt-admin-time-helper</source>
        <translation>lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <location filename="../nosdtimedatectl.cpp" line="145"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Не вдалося виконати дію (%1):&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="46"/>
        <source>Time and date configuration</source>
        <translation>Налаштування часу і дати</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="52"/>
        <source>Date and time</source>
        <translation>Дата і час</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="60"/>
        <source>Timezone</source>
        <translation>Часова зона</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="123"/>
        <location filename="../timeadmindialog.cpp" line="133"/>
        <location filename="../timeadmindialog.cpp" line="140"/>
        <location filename="../timeadmindialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>Зміна RTC на місцевий час вимагає перезавантаження</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>Зміна RTC на UTC вимагає перезавантаження</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="158"/>
        <source>Reboot required</source>
        <translation>Перезавантаження обов&apos;язкове</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Ваша теперішня часова зона:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>Фільтр</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Нічого</translation>
    </message>
</context>
</TS>
